All Classes and Interfaces

Class
Description
An Access Control List.
 
An ACL with the specified name already exists.
 
The specified ACL does not exist.
 
Returns the updates being applied to the ACL.
 
The request cannot be processed because it would exceed the maximum number of ACLs allowed.
 
The status of the ACL update
 
The customer has exceeded the maximum number of API requests allowed per time period.
 
An AWS Arn.
Denotes the user's authentication properties, such as whether it requires a password to authenticate.
 
Denotes the user's authentication properties, such as whether it requires a password to authenticate.
 
 
Indicates if the cluster has a Multi-AZ configuration (multiaz) or not (singleaz).
 
 
 
 
 
 
 
Contains all of the attributes of a specific cluster.
 
A cluster with the specified name already exists.
 
A list of cluster configuration options.
 
The specified cluster does not exist.
 
A list of updates being applied to the cluster
 
The request cannot be processed because it would exceed the maximum number of clusters allowed for this customer.
 
 
 
 
 
 
 
CreateAclRequest Marshaller
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
A default user is required and must be specified.
 
 
 
DeleteAclRequest Marshaller
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Represents the output for the MemoryDbClient.describeACLsPaginator(software.amazon.awssdk.services.memorydb.model.DescribeAcLsRequest) operation which is a paginated operation.
Represents the output for the MemoryDbAsyncClient.describeACLsPaginator(software.amazon.awssdk.services.memorydb.model.DescribeAcLsRequest) operation which is a paginated operation.
 
 
 
 
 
 
 
 
 
 
 
 
Represents the output for the MemoryDbClient.describeEventsPaginator(software.amazon.awssdk.services.memorydb.model.DescribeEventsRequest) operation which is a paginated operation.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Represents the output for the MemoryDbClient.describeUsersPaginator(software.amazon.awssdk.services.memorydb.model.DescribeUsersRequest) operation which is a paginated operation.
 
 
 
 
A user with the specified name already exists.
 
Represents the information required for client programs to connect to the cluster and its nodes.
 
Link between an endpoint property and the AwsEndpointAttribute it represents.
 
 
Provides details of the Redis OSS engine version
 
Represents a single occurrence of something interesting within the system.
 
 
 
 
 
Used to streamline results of a search based on the property being filtered.
 
Identifiers for variables declared within the rule engine, e.g.
 
The cluster does not have sufficient capacity to perform the requested operation.
 
The ACL is not in a valid state for the requested operation.
 
The specified Amazon Resource Name (ARN) is not valid.
 
The cluster is not in a valid state for the requested operation.
 
The provided credentials are not valid.
 
The specified KMS key is not valid or accessible.
 
The requested operation cannot be performed on the multi-Region cluster in its current state.
 
The node is not in a valid state for the requested operation.
 
The specified parameter combination is not valid.
 
The parameter group is not in a valid state for the requested operation.
 
The specified parameter value is not valid.
 
The snapshot is not in a valid state for the requested operation.
 
The specified subnet is not valid.
 
The user is not in a valid state for the requested operation.
 
The VPC network is not in a valid state for the requested operation.
 
 
 
 
 
 
 
 
 
 
 
 
ListTagsRequest Marshaller
 
 
Service client for accessing Amazon MemoryDB asynchronously.
A builder for creating an instance of MemoryDbAsyncClient.
 
The parameters object used to resolve the auth schemes for the MemoryDb service.
A builder for a MemoryDbAuthSchemeParams.
An auth scheme provider for MemoryDb service.
This includes configuration specific to Amazon MemoryDB that is supported by both MemoryDbClientBuilder and MemoryDbAsyncClientBuilder.
Service client for accessing Amazon MemoryDB.
A builder for creating an instance of MemoryDbClient.
 
The parameters object used to resolve an endpoint for the MemoryDb service.
 
An endpoint provider for MemoryDb.
 
 
 
 
 
 
 
 
 
 
 
 
Class to expose the service client settings to the user.
A builder for creating a MemoryDbServiceClientConfiguration
 
Represents a multi-Region cluster.
 
A multi-Region cluster with the specified name already exists.
 
The specified multi-Region cluster does not exist.
 
Describes an individual setting that controls some aspect of MemoryDB behavior across multiple regions.
 
Represents the output of a CreateMultiRegionParameterGroup operation.
 
The specified multi-Region parameter group does not exist.
 
 
Represents an individual node within a cluster.
 
The request cannot be processed because it would exceed the maximum number of nodes allowed for this cluster.
 
The request cannot be processed because it would exceed the maximum number of nodes allowed for this customer.
 
The requested operation would result in no changes.
 
 
 
Describes an individual setting that controls some aspect of MemoryDB behavior.
 
Represents the output of a CreateParameterGroup operation.
 
A parameter group with the specified name already exists.
 
The specified parameter group does not exist.
 
The request cannot be processed because it would exceed the maximum number of parameter groups allowed.
 
Describes a name-value pair that is used to update the value of a parameter.
 
 
 
 
 
 
Update action that has yet to be processed for the corresponding apply/stop request
 
 
 
 
 
 
The recurring charge to run this reserved node.
 
Represents a Regional cluster
 
 
 
A request to configure the number of replicas in a shard
 
Represents the output of a PurchaseReservedNodesOffering operation.
 
You already have a reservation with the given identifier.
 
The requested node does not exist.
 
The request cannot be processed because it would exceed the user's node quota.
 
The offering type of this node.
 
The requested node offering does not exist.
 
 
 
 
 
The status of the online resharding
 
 
 
 
 
 
Represents a URL to be used internally for endpoint resolution.
Represents a single security group and its status.
 
The required service-linked role was not found.
 
An update that you can apply to your MemoryDB clusters.
 
The specified service update does not exist.
 
A request to apply a service update
 
 
 
 
Represents a collection of nodes in a cluster.
 
Shard configuration options.
 
A request to configure the sharding properties of a cluster
 
Provides details of a shard in a snapshot
 
The specified shard does not exist.
 
The request cannot be processed because it would exceed the maximum number of shards allowed per cluster.
 
Represents the progress of an online resharding operation.
 
Represents a copy of an entire cluster as of the time when the snapshot was taken.
 
A snapshot with the specified name already exists.
 
The specified snapshot does not exist.
 
The request cannot be processed because it would exceed the maximum number of snapshots allowed.
 
 
Represents the subnet associated with a cluster.
 
Represents the output of one of the following operations:
 
A subnet group with the specified name already exists.
 
The subnet group is currently in use and cannot be deleted.
 
The specified subnet group does not exist.
 
The request cannot be processed because it would exceed the maximum number of subnet groups allowed.
 
The subnet is currently in use and cannot be deleted.
 
The specified subnet is not allowed for this operation.
 
The request cannot be processed because it would exceed the maximum number of subnets allowed.
 
A tag that can be added to an MemoryDB resource.
 
The specified tag does not exist.
 
The request cannot be processed because it would exceed the maximum number of tags allowed per resource.
 
 
 
 
 
Test failover is not available for this cluster configuration.
 
A cluster whose updates have failed
 
 
 
 
 
 
 
UpdateAclRequest Marshaller
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
You create users and assign them specific permissions by using an access string.
 
 
A user with the specified name already exists.
 
The specified user does not exist.
 
The request cannot be processed because it would exceed the maximum number of users allowed.
 
Base class for the types of values computable by the RuleEngine.
An array value.
A boolean value.
 
 
An integer value.
 
A record (map) value.
A string value.